@@ -3,6 +3,20 @@ from calaccess_raw import models
 from .base import BaseAdmin
 
 
+class FilernameCdAdmin(BaseAdmin):
+    list_display = (
+        "id",
+        "xref_filer_id",
+        "filer_id",
+        "naml",
+        "namf",
+        "filer_type",
+        "status",
+        "effect_dt",
+    )
+    list_filter = ("filer_type",)
+
+
 class FilerFilingsCdAdmin(BaseAdmin):
     pass
 
@@ -23,6 +37,7 @@ class CvrE530CdAdmin(BaseAdmin):
     pass
 
 
+admin.site.register(models.FilernameCd, FilernameCdAdmin)
 admin.site.register(models.FilerFilingsCd, FilerFilingsCdAdmin)
 admin.site.register(models.FilingsCd, FilingsCdAdmin)
 admin.site.register(models.SmryCd, SmryCdAdmin)
